@@ -46,7 +46,7 @@ type ExpectedBpfstatsEvent struct {
 
 type testDef struct {
 	runnerConfig   *utils.RunnerConfig
-	allPrograms    bool
+	gadgetsOnly    bool
 	generateEvent  func(t *testing.T)
 	expectedEvents []ExpectedBpfstatsEvent
 }
@@ -69,6 +69,7 @@ func TestBpfstatsGadget(t *testing.T) {
 		"by_gadget": {
 			runnerConfig:  runnerConfig,
 			generateEvent: generateEvent,
+			gadgetsOnly:   true,
 			expectedEvents: []ExpectedBpfstatsEvent{
 				{
 					GadgetImage: gadgetrunner.GetGadgetImageName(testGadgetImage),
@@ -79,7 +80,7 @@ func TestBpfstatsGadget(t *testing.T) {
 		"by_programs": {
 			runnerConfig:  runnerConfig,
 			generateEvent: generateEvent,
-			allPrograms:   true,
+			gadgetsOnly:   false,
 			expectedEvents: []ExpectedBpfstatsEvent{
 				// programs from trace_open gadget. This introduces a dependency
 				// on the trace_open gadget, but it's almost guaranteed that this
@@ -129,8 +130,8 @@ func TestBpfstatsGadget(t *testing.T) {
 			}
 
 			var paramValues map[string]string
-			if testCase.allPrograms {
-				paramValues = map[string]string{"operator.ebpf.all": "true"}
+			if testCase.gadgetsOnly {
+				paramValues = map[string]string{"operator.ebpf.gadgets-only": "true"}
 			}
 
 			opts := gadgetrunner.GadgetRunnerOpts[ExpectedBpfstatsEvent]{
